==> v0.1.1.zip: hugo-academic-mirror/starters/academic-cv/content/authors/admin/_index.md <==
---
# Display name
title: 吳健雄

# Name pronunciation (optional)
name_pronunciation: Chien Shiung Wu

# Full name (for SEO)
first_name: Shiung Wu
last_name: Chien

# Status emoji
status:
  icon: ☕️

# Is this the primary user of the site?
superuser: true

# Role/position/tagline
role: Professor of Artificial Intelligence

# Organizations/Affiliations to show in About widget
organizations:
  - name: Stanford University
    url: https://www.stanford.edu/

# Short bio (displayed in user profile at end of posts)
bio: My research interests include distributed robotics, mobile computing and programmable matter.

# Interests to show in About widget
interests:
  - Artificial Intelligence
  - Computational Linguistics
  - Information Retrieval

# Education to show in About widget
education:
  courses:
    - course: PhD in Artificial Intelligence
      institution: Stanford University
      year: 2012
    - course: MEng in Artificial Intelligence
      institution: Massachusetts Institute of Technology
      year: 2009
    - course: BSc in Artificial Intelligence
      institution: Massachusetts Institute of Technology
      year: 2008

# Skills
# For available icons, see: https://docs.hugoblox.com/getting-started/page-builder/#icons
skills:
  - name: Technical
    items:
      - name: Python
        description: ''
        percent: 80
        icon: python
        icon_pack: fab
      - name: Data Science
        description: ''
        percent: 100
        icon: chart-line
        icon_pack: fas
      - name: SQL
        description: ''
        percent: 40
        icon: database
        icon_pack: fas
  - name: Hobbies
    color: '#eeac02'
    color_border: '#f0bf23'
    items:
      - name: Hiking
        description: ''
        percent: 60
        icon: person-hiking
        icon_pack: fas
      - name: Cats
        description: ''
        percent: 100
        icon: cat
        icon_pack: fas
      - name: Photography
        description: ''
        percent: 80
        icon: camera-retro
        icon_pack: fas

# Social/Academic Networking
# For available icons, see: https://docs.hugoblox.com/getting-started/page-builder/#icons
#   For an email link, use "fas" icon pack, "envelope" icon, and a link in the
#   form "mailto:your-email@example.com" or "/#contact" for contact widget.
social:
  - icon: envelope
    icon_pack: fas
    link: '/#contact'
  - icon: twitter
    icon_pack: fab
    link: https://twitter.com/GeorgeCushen
    label: Follow me on Twitter
    display:
      header: true
  - icon: graduation-cap # Alternatively, use `google-scholar` icon from `ai` icon pack
    icon_pack: fas
    link: https://scholar.google.co.uk/citations?user=sIwtMXoAAAAJ
  - icon: github
    icon_pack: fab
    link: https://github.com/gcushen
  - icon: linkedin
    icon_pack: fab
    link: https://www.linkedin.com/
  # Link to a PDF of your resume/CV.
  # To use: copy your resume to `static/uploads/resume.pdf`, enable `ai` icons in `params.yaml`,
  # and uncomment the lines below.
  - icon: cv
    icon_pack: ai
    link: uploads/resume.pdf

# Highlight the author in author lists? (true/false)
highlight_name: true
---

Chien Shiung Wu is a professor of artificial intelligence at the Stanford AI Lab. Her research interests include distributed robotics, mobile computing and programmable matter. She leads the Robotic Neurobiology group, which develops self-reconfiguring robots, systems of self-organizing robots, and mobile sensor networks.
{style="text-align: justify;"}

==> v5.9.5.zip: hugo-academic-mirror/starters/academic-cv/content/authors/admin/_index.md <==
---
# Display name
title: 吳健雄

# Name pronunciation (optional)
name_pronunciation: Chien Shiung Wu

# Full name (for SEO)
first_name: Shiung Wu
last_name: Chien

# Status emoji
status:
  icon: ☕️

# Is this the primary user of the site?
superuser: true

# Role/position/tagline
role: Professor of Artificial Intelligence

# Organizations/Affiliations to show in About widget
organizations:
  - name: Stanford University
    url: https://www.stanford.edu/

# Short bio (displayed in user profile at end of posts)
bio: My research interests include distributed robotics, mobile computing and programmable matter.

# Interests to show in About widget
interests:
  - Artificial Intelligence
  - Computational Linguistics
  - Information Retrieval

# Education to show in About widget
education:
  courses:
    - course: PhD in Artificial Intelligence
      institution: Stanford University
      year: 2012
    - course: MEng in Artificial Intelligence
      institution: Massachusetts Institute of Technology
      year: 2009
    - course: BSc in Artificial Intelligence
      institution: Massachusetts Institute of Technology
      year: 2008

# Skills
# For available icons, see: https://hugoblox.com/docs/getting-started/page-builder/#icons
skills:
  - name: Technical
    items:
      - name: Python
        description: ''
        percent: 80
        icon: python
        icon_pack: fab
      - name: Data Science
        description: ''
        percent: 100
        icon: chart-line
        icon_pack: fas
      - name: SQL
        description: ''
        percent: 40
        icon: database
        icon_pack: fas
  - name: Hobbies
    color: '#eeac02'
    color_border: '#f0bf23'
    items:
      - name: Hiking
        description: ''
        percent: 60
        icon: person-hiking
        icon_pack: fas
      - name: Cats
        description: ''
        percent: 100
        icon: cat
        icon_pack: fas
      - name: Photography
        description: ''
        percent: 80
        icon: camera-retro
        icon_pack: fas

# Social/Academic Networking
# For available icons, see: https://hugoblox.com/docs/getting-started/page-builder/#icons
#   For an email link, use "fas" icon pack, "envelope" icon, and a link in the
#   form "mailto:your-email@example.com" or "/#contact" for contact widget.
social:
  - icon: envelope
    icon_pack: fas
    link: '/#contact'
  - icon: twitter
    icon_pack: fab
    link: https://twitter.com/GeorgeCushen
    label: Follow me on Twitter
    display:
      header: true
  - icon: graduation-cap # Alternatively, use `google-scholar` icon from `ai` icon pack
    icon_pack: fas
    link: https://scholar.google.co.uk/citations?user=sIwtMXoAAAAJ
  - icon: github
    icon_pack: fab
    link: https://github.com/gcushen
  - icon: linkedin
    icon_pack: fab
    link: https://www.linkedin.com/
  # Link to a PDF of your resume/CV.
  # To use: copy your resume to `static/uploads/resume.pdf`, enable `ai` icons in `params.yaml`,
  # and uncomment the lines below.
  - icon: cv
    icon_pack: ai
    link: uploads/resume.pdf

# Highlight the author in author lists? (true/false)
highlight_name: true
---

Chien Shiung Wu is a professor of artificial intelligence at the Stanford AI Lab. Her research interests include distributed robotics, mobile computing and programmable matter. She leads the Robotic Neurobiology group, which develops self-reconfiguring robots, systems of self-organizing robots, and mobile sensor networks.
{style="text-align: justify;"}
